@@ -15,6 +15,7 @@ import struct
 import sys
 import zipfile
 
+from importlib.util import MAGIC_NUMBER
 from glob import glob
 
 from .resources import UpdateResources
@@ -154,12 +155,14 @@ class Runtime(object):
 
         self.options.excludes = self.options.excludes if self.options.excludes else []
         self.options.optimize = self.options.optimize if self.options.optimize else 0
+        self.options.dll_excludes = self.options.dll_excludes if self.options.dll_excludes else []
 
     def analyze(self):
         logger.info("Analyzing the code")
 
         mf = self.mf = Scanner(excludes=self.options.excludes,
-                               optimize=self.options.optimize)
+                               optimize=self.options.optimize,
+                               dll_excludes=self.options.dll_excludes)
 
         for modname in self.bootstrap_modules:
             if modname.endswith(".*"):
@@ -296,7 +299,7 @@ class Runtime(object):
                     shutil.copy2(src, dst)
 
     def get_runstub_bytes(self, target):
-        from distutils.util import get_platform
+        from sysconfig import get_platform
         if target.exe_type in ("console_exe", "service"):
             run_stub = 'run-py%s.%s-%s.exe' % (sys.version_info[0], sys.version_info[1], get_platform())
         elif target.exe_type == "windows_exe":
@@ -358,24 +361,9 @@ class Runtime(object):
                 res_writer.add(type=res_type, name=res_name, value=res_data)
 
             # Build and add a versioninfo resource
-
-            # XXX better use resource.add_version(target) ???  would look nicer...
-            if hasattr(target, "version"):
-                def get(name):
-                    return getattr(target, name, None)
-                version = Version(target.version,
-                                  file_description = get("description"),
-                                  comments = get("comments"),
-                                  company_name = get("company_name"),
-                                  legal_copyright = get("copyright"),
-                                  legal_trademarks = get("trademarks"),
-                                  original_filename = os.path.basename(exe_path),
-                                  product_name = get("product_name"),
-                                  product_version = get("product_version") or target.version,
-                                  internal_name = get("internal_name"),
-                                  private_build = get("private_build"),
-                                  special_build = get("special_build"))
-
+            if self.options.version_info:
+                self.options.version_info.original_filename = os.path.basename(exe_path)
+                version = Version(self.options.version_info)
 
                 from ._wapi import RT_VERSION
                 res_writer.add(type=RT_VERSION,
@@ -427,7 +415,7 @@ class Runtime(object):
             if mod.get_code_runtime():
                 path = mod.__dest_file__
                 stream = io.BytesIO()
-                stream.write(imp.get_magic())
+                stream.write(MAGIC_NUMBER)
                 if sys.version_info >= (3,7,0):
                     stream.write(b"\0\0\0\0") # null flags
                 stream.write(b"\0\0\0\0") # null timestamp
@@ -460,7 +448,7 @@ class Runtime(object):
                                    optimize=self.options.optimize)
                     path = mod.__dest_file__
                     stream = io.BytesIO()
-                    stream.write(imp.get_magic())
+                    stream.write(MAGIC_NUMBER)
                     if sys.version_info >= (3,7,0):
                         stream.write(b"\0\0\0\0") # null flags
                     stream.write(b"\0\0\0\0") # null timestamp
@@ -474,7 +462,7 @@ class Runtime(object):
                 path = mod.__name__.replace(".", "\\") + "\\__init__" + bytecode_suffix
                 code = compile(r"", path, "exec", optimize=self.options.optimize)
                 stream = io.BytesIO()
-                stream.write(imp.get_magic())
+                stream.write(MAGIC_NUMBER)
                 if sys.version_info >= (3,7,0):
                     stream.write(b"\0\0\0\0") # null flags
                 stream.write(b"\0\0\0\0") # null timestamp
